import json

from django.core.management.base import BaseCommand


from 臺灣言語服務.models import 訓練過渡格式


class Command(BaseCommand):
    help = '匯入高明達聽拍的twisas資料庫'

    公家內容 = {
        '來源': '台文資料庫',
        '種類': '語句',
        '年代': '2018',
    }

    def add_arguments(self, parser):
        parser.add_argument(
            '聽拍json',  type=str
        )

    def handle(self, *args, **參數):
        self.stdout.write('資料數量：{}'.format(訓練過渡格式.資料數量()))

        全部資料 = []
        匯入數量 = 0
        with open(參數['聽拍json']) as 檔案:
            for 資料 in json.load(檔案):
                全部資料.append(
                    訓練過渡格式(
                        影音所在=資料['影音所在'],
                        聽拍=資料['聽拍資料'],
                        **self.公家內容
                    )
                )

                匯入數量 += 1
                if 匯入數量 % 100 == 0:
                    self.stdout.write('匯入 {} 筆'.format(匯入數量))

        self.stdout.write('檢查格式了匯入')
        訓練過渡格式.加一堆資料(全部資料)

        self.stdout.write('資料數量：{}'.format(訓練過渡格式.資料數量()))



import json
from os.path import basename, dirname

from django.core.management.base import BaseCommand


from 臺灣言語資料庫.資料模型 import 影音表
from 臺灣言語資料庫.資料模型 import 來源表
from 臺灣言語資料庫.資料模型 import 版權表
from 臺灣言語資料庫.資料模型 import 資料表工具
from 程式.全漢全羅.匯入檔案揣資料夾 import 揣資料夾內的語料


class Command(BaseCommand):
    help = '匯入高明達聽拍的資料庫'

    def add_arguments(self, parser):
        parser.add_argument(
            'json資料夾所在',  type=str
        )
        parser.add_argument(
            'wav資料夾所在',  type=str
        )

    def handle(self, *args, **參數):
        self.stdout.write(資料表工具.顯示資料數量())
        公家內容 = {
            '收錄者': 來源表.objects.get_or_create(名='系統管理員')[0],
            '來源': {'名': '台文資料庫'},
            '版權': 版權表.objects.get_or_create(版權='會使公開')[0],
            '種類': '語句',
            '語言腔口': '閩南語',
            '著作所在地': '臺灣',
            '著作年': '2015',
        }
        try:
            for json檔名, wav檔名 in 揣資料夾內的語料(參數['json資料夾所在'], 參數['wav資料夾所在']):
                影音內容 = {'影音所在': wav檔名}
                影音內容.update(公家內容)
                影音 = 影音表.加資料(影音內容)
                with open(json檔名) as json檔案:
                    json資料 = json.load(json檔案)
                資料夾名 = basename(dirname(wav檔名))
                聲音檔名 = basename(wav檔名)
                for 一筆 in json資料:
                    一筆['文本資料'] = 一筆['漢字']
                    一筆['音標資料'] = 一筆['臺羅']
                    一筆['內容'] = 一筆['分詞']
                    一筆['語者'] = 語者照資料夾(資料夾名, 聲音檔名, 一筆['語者'])
                聽拍內容 = {'聽拍資料': json資料}
                聽拍內容.update(公家內容)
                影音.寫聽拍(聽拍內容)
        except KeyboardInterrupt as 錯誤:
            print(錯誤)
        self.stdout.write(資料表工具.顯示資料數量())


def 語者照資料夾(資料夾, 檔名, 語者):
    if 資料夾 in [
        'ALen&Tea',
        'DaAi_blktc',
        'DaAi_csgr',
        'DaAi_urs',
        'DaAi_vvrs',
        'LTS',
        'MH',
        'Neighbor',
    ]:
        return '{}-{}'.format(資料夾, 語者)
    if 資料夾 in ['Dream_State']:
        if 語者 == '主持人':
            return '{}-{}'.format(資料夾, 語者)
        return '{}-{}-{}'.format(資料夾, 檔名, 語者)
    if 資料夾 in [
        'FTVN-1',
        'FTVN-2',
        'FTVN-3',
        'FTVN-4',
        'PTSN-1',
        'PTSN-2',
        'PTSN-3',
    ]:
        return '{}-{}-{}'.format(資料夾, 檔名, 語者)
    if 資料夾 == 'TW03':
        return '{}-{}'.format(
            資料夾,
            檔名.split('0')[0].replace(' ', '_').strip('012345_')
        )
    if 資料夾 == 'EDU':
        return '{}-{}'.format(
            資料夾,
            檔名
        )
    raise RuntimeError('「{}」資料夾無設定'.format(資料夾))



from distutils.core import setup
from os import walk
import os
import sys


def 讀(檔名):
    return open(os.path.join(os.path.dirname(__file__), 檔名)).read()


def 揣工具包(頭):
    'setup的find_packages無支援windows中文檔案'
    工具包 = []
    for 目錄, _, 檔案 in walk(頭):
        if '__init__.py' in 檔案:
            工具包.append(目錄.replace('/', '.'))
    return 工具包


setup(
    name='twisas',
    packages=揣工具包('twisas'),
    version='0.1.0',
    description='twisas',
    long_description=讀('README.md'),
    author='薛丞宏',
    author_email='ihcaoe@gmail.com',
    keywords=[
        'Corpus', '語料庫',
        'Taiwan', 'Taiwanese',
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Operating System :: Unix',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    install_requires=[
        'tai5-uan5_gian5-gi2_hok8-bu7',
    ]
)
